@@ -117,12 +117,12 @@ save_machine_uuid (const char *uuid_arg)
 /* Read the machine uuid from file if needed. Returns TRUE if machine_uuid is
  * set after this function */
 static int
-read_machine_uuid_if_needed (void)
+read_machine_uuid_if_needed (DBusError *error)
 {
   if (machine_uuid != NULL)
     return TRUE;
 
-  machine_uuid = dbus_get_local_machine_id ();
+  machine_uuid = dbus_try_get_local_machine_id (error);
 
   if (machine_uuid == NULL)
     return FALSE;
@@ -459,19 +459,12 @@ print_variables (const char *bus_address, pid_t bus_pid, long bus_wid,
     }
 }
 
-static int got_sighup = FALSE;
+static int got_fatal_signal = 0;
 
 static void
 signal_handler (int sig)
 {
-  switch (sig)
-    {
-    case SIGHUP:
-    case SIGINT:
-    case SIGTERM:
-      got_sighup = TRUE;
-      break;
-    }
+  got_fatal_signal = sig;
 }
 
 static void kill_bus_when_session_ends (void) _DBUS_GNUC_NORETURN;
@@ -487,7 +480,7 @@ kill_bus_when_session_ends (void)
   sigset_t empty_mask;
   
   /* install SIGHUP handler */
-  got_sighup = FALSE;
+  got_fatal_signal = 0;
   sigemptyset (&empty_mask);
   act.sa_handler = signal_handler;
   act.sa_mask    = empty_mask;
@@ -564,9 +557,10 @@ kill_bus_when_session_ends (void)
       select (MAX (tty_fd, x_fd) + 1,
               &read_set, NULL, &err_set, NULL);
 
-      if (got_sighup)
+      if (got_fatal_signal)
         {
-          verbose ("Got SIGHUP, exiting\n");
+          verbose ("Got fatal signal %d, killing dbus-daemon\n",
+                   got_fatal_signal);
           kill_bus_and_exit (0);
         }
       
@@ -709,6 +703,8 @@ babysit (int   exit_with_session,
 	       strerror (errno));
       exit (1);
       break;
+    default:
+      _dbus_assert_not_reached ("Invalid read result");
     }
 
   verbose ("Got PID %ld from daemon\n",
@@ -845,6 +841,7 @@ main (int argc, char **argv)
   dbus_bool_t user_bus_supported = FALSE;
   DBusString user_bus;
   const char *error_str;
+  DBusError error = DBUS_ERROR_INIT;
 
   exit_with_session = FALSE;
   config_file = NULL;
@@ -1017,7 +1014,6 @@ main (int argc, char **argv)
       char *address;
       pid_t pid;
       long wid;
-      DBusError error = DBUS_ERROR_INIT;
       
       if (get_machine_uuid () == NULL)
         {
@@ -1091,9 +1087,10 @@ main (int argc, char **argv)
       fprintf (stderr, "Session lifetime based on X11 requested, but X11 support not compiled in.\n");
       exit (1);
 #else /* DBUS_BUILD_X11 */
-      if (!read_machine_uuid_if_needed())
+      if (!read_machine_uuid_if_needed (&error))
         {
-          fprintf (stderr, "Session lifetime based on X11 requested, but machine UUID unavailable.\n");
+          fprintf (stderr, "Session lifetime based on X11 requested, but machine UUID unavailable: %s.\n", error.message);
+          dbus_error_free (&error);
           exit (1);
         }
 
@@ -1105,10 +1102,16 @@ main (int argc, char **argv)
 #endif /* DBUS_BUILD_X11 */
     }
 #ifdef DBUS_BUILD_X11
-  else if (read_machine_uuid_if_needed())
+  else if (read_machine_uuid_if_needed (&error))
     {
       x11_init();
     }
+  else
+    {
+      /* Survive this misconfiguration, but complain about it. */
+      fprintf (stderr, "%s\n", error.message);
+      dbus_error_free (&error);
+    }
 #endif /* DBUS_BUILD_X11 */
 
 
@@ -1328,6 +1331,8 @@ main (int argc, char **argv)
                    strerror (errno));
           exit (1);
           break;
+        default:
+          _dbus_assert_not_reached ("Invalid read result");
         }
         
       close (bus_address_to_launcher_pipe[READ_END]);
@@ -1347,6 +1352,8 @@ main (int argc, char **argv)
 		   strerror (errno));
 	  exit (1);
 	  break;
+	default:
+	  _dbus_assert_not_reached ("Invalid read result");
 	}
 
       end = NULL;
